Learn R Programming

libamtrack (version 0.6.3)

AT.CPPSC.alpha.and.beta: AT.CPPSC.alpha.and.beta

Description

Returns alpha and beta for an ion survival curve predicted by the CPPSC model. The arguments are directly passed on to the AT.run.CPPSC.method routine, some are provided default values here to simplify the use. !! THIS ROUTINE IS LIMITED TO THE LIN-QUAD MODEL BUT SHOULD BE GENERALIZED FOR ANY GAMMA REPONSE, BOTH IN TERMS OF INPUT X RAY PARAMETERS *AND* OF RETURNED (FITTED) ION PARAMETERS!! Cave: Even if input X ray response is LQ with cut dose, the resulting LQ will be purely linear-quadratic without high-dose linear characteristic.

Usage

AT.CPPSC.alpha.and.beta(E.MeV.u, particle.no, fluence.cm2.or.dose.Gy, material.no, RDD.model, RDD.parameters, ER.model, gamma.model, gamma.parameters, N2 = 20, fluence.factor = 1.0, write.output = FALSE, shrink.tails = TRUE, shrink.tails.under = 1e-30, adjust.N2 = TRUE)

Arguments

E.MeV.u
Energy
particle.no
Particle index
fluence.cm2.or.dose.Gy
Mean dose - will be varied for survival / response in a range 0.1x-10x.
material.no
Material index
RDD.model
RDD index
RDD.parameters
RDD parameters
ER.model
ER index
gamma.model
gamma model index, must be LQ = 5
gamma.parameters
gamma parameters, here alpha, beta, Dcut
N2
defaulted
fluence.factor
defaulted
write.output
defaulted
shrink.tails
defaulted
shrink.tails.under
defaulted
adjust.N2
defaulted

Value

List with follwing items
alpha
alpha for ion response curve
beta
beta for ion response curve
df
data frame with complete ion response curve as computed to find alpha and beta including residuals fo that fit.

Examples

Run this code
# None yet

Run the code above in your browser using DataLab