Learn R Programming

libamtrack (version 0.6.3)

AT.FLUKA.particle.name.to.libamtrack.particle.name: AT.FLUKA.particle.name.to.libamtrack.particle.name

Description

Coverts FLUKA style particle names to libamtrack convention.

Usage

AT.FLUKA.particle.name.to.libamtrack.particle.name( FLUKA.particle.names)

Arguments

FLUKA.particle.names
vector of strings containing the FLUKA-style particle names

Value

Character string vector with libamtrack-style particle names.

Details

FLUKA particle names relating to all particle with a specific Z, e.g. LI* or H*, will be translated to the 'even' isotope A = 2*Z. The only exception is H* which will be replaced by 1H. For example, LI* --> 6Li, C* --> 12C, BE* --> 8Be. This is a pure convention and does not necessarily represent the most prominent isotope. For most computations which only rely on Z it is, however, valid.

Examples

Run this code
AT.FLUKA.particle.name.to.libamtrack.particle.name( FLUKA.particle.names =
 c("H*", "B*", "B10", "C12", "BE7", "U238") )

Run the code above in your browser using DataLab