Learn R Programming

libamtrack (version 0.6.3)

AT.FLUKA.read.USRBIN.mesh: AT.FLUKA.read.USRBIN.mesh

Description

Reads USRBIN output for Cartesian mesh, also for multiple output files from cluster runs. As USRBIN (mesh) scores energy deposited per unit volume per primary weight (GeV/cm3), the density as to be given for dose computation.

Usage

AT.FLUKA.read.USRBIN.mesh(exp.name, number.of.runs, unit, data.source = 'local', density.g.cm3 = 1.0)

Arguments

exp.name
Experiment name, i.e. name of input file (without '.inp' extension)
number.of.runs
Number of output files from parallel (cluster) runs.
unit
FLUKA output unit number
data.source
'local' if output files are from a local machine, 'condor' if from condor cluster, 'condor_cleaned' if from condor cluster with clean option (-c) in rcfluka.py
density.g.cm3
Physical density of material in mesh, needed for computation of dose.

Value

Data frame with deposited energy, deposited dose (and in case of multiple runs estimate of their standard deviation) for each mesh cell.

Examples

Run this code
# None yet, requires FLUKA output file

Run the code above in your browser using DataLab