Learn R Programming

libamtrack (version 0.6.3)

AT.FLUKA.read.USRTRACK: AT.FLUKA.read.USRTRACK

Description

Reads USRTRACK output (for energy spectra scoring using fluscw.SPC.f) for a series of regions, also for multiple output files from cluster runs (using rcfluka.py). USRTRACK scores the fluence per primary weight per bin width(cm-2/GeV) but only if the correct volume of the corresponding regions is given in the FLUKA input card! AT.FLUKA.read.USRTRACK will however out the absolute fluence for each energy bin (in cm-2) as this can be directly used by libamtrack.

Usage

AT.FLUKA.read.USRTRACK(exp.name, number.of.runs, unit, data.source = 'local', compress = TRUE)

Arguments

exp.name
Experiment name, i.e. name of input file (without '.inp' extension)
number.of.runs
Number of output files from parallel (cluster) runs.
unit
FLUKA output unit number
data.source
'local' if output files are from a local machine, 'condor' if from condor cluster, 'condor_cleaned' if from condor cluster with clean option (-c) in rcfluka.py
compress
If TRUE, all entries with zero fluence will be removed from resulting data frame in order to save memory.

Value

Data frame with midpoints and widths of energy bins, particle index no particle.no, and fluence (absolute [cm-2], i.e. not normalized to bin width!) for each region.

Examples

Run this code
# None yet, requires FLUKA output file

Run the code above in your browser using DataLab