Learn R Programming

libamtrack (version 0.6.3)

AT.SPC.convert.to.DDD: AT.SPC.convert.to.DDD

Description

Converts spectral fluence data differential in depth and energy (spc) into a depth-dose. It also allows for the export of TRiP98 compatible DDD files. The routine calls AT.SPC.read so if you experience problems, please check if additional arguments for AT.SPC.read are needed (via '...'). For the DDD format, see M. Kr\"amer's TRiP98 documentation: http://bio.gsi.de/DOCS/TRiP98BEAM/DOCS/trip98fmtddd.html.

Usage

AT.SPC.convert.to.DDD(file.name.spc, file.name.ddd = NULL, endian = 'little', plot = TRUE, write = TRUE, ...)

Arguments

file.name.spc
path and file name for spc data
file.name.ddd
path and file name for ddd data, if not given file.name.spc will be used but with *.ddd extension (only applicable if write = TRUE
endian
endianess of spc data, see also AT.SPC.read
plot
if true, the resulting depth-dose curve will be plotted, e.g. for error-checking
write
if true, the resulting depth-dose curve will be exported in TRiP98 format
...
additional arguments for the AT.SPC.read routine

Value

A data frame containing the depth-dose curve