Learn R Programming

libamtrack (version 0.6.3)

AT.SPC.spectrum.at.depth.g.cm2: AT.SPC.spectrum.at.depth.g.cm2

Description

Returns spectrum from spc data in given depth step.

Usage

AT.SPC.spectrum.at.depth.g.cm2( spc, depth.g.cm2, interpolate = TRUE)

Arguments

spc
spc data
depth.g.cm2
depth the spectrum should be taken at (up to now, the data from the closest depth step will be taken)
interpolate
if true, the spectra between the closest depth steps will be linearly interpolated, if false, the depth step just in front of the chosen depth will be taken directly

Value

A data frame with the following columns (ready to use in most libamtrack functions):
E.MeV.u
Energy [MeV/u] - mid point of bin
particle.no
Particle index number
fluence.cm2
Fluence for each bin

See Also

Uses AT.SPC.spectrum.at.depth.step. spc data should be read in by AT.SPC.read.

Examples

Run this code
# None yet.

Run the code above in your browser using DataLab