Learn R Programming

libamtrack (version 0.6.3)

AT.SPC.spectrum.at.depth.step: AT.SPC.spectrum.at.depth.step

Description

Returns spectrum from spc data in given depth step.

Usage

AT.SPC.spectrum.at.depth.step( spc, depth.step)

Arguments

spc
spc data
depth.step
depth step the spectrum should be taken from (if outside data scope an errormessage will be issued)

Value

A data frame with the following columns (ready to use in most libamtrack functions):
E.MeV.u
Energy [MeV/u] - mid point of bin
particle.no
Particle index number
fluence.cm2
Fluence for each bin

See Also

Use AT.SPC.spectrum.at.depth.g.cm2 to get spectrum at given depth. spc data should be read in by AT.SPC.read.

Examples

Run this code
# None yet.

Run the code above in your browser using DataLab