Learn R Programming

libamtrack (version 0.6.3)

AT.dose.weighted.E.MeV.u: AT.dose.weighted.E.MeV.u

Description

Computes the dose-weighted average energy of a particle field Needed by SuccessiveConvolutions

Usage

AT.dose.weighted.E.MeV.u(E.MeV.u, particle.no, fluence.cm2,
 material.no, stopping.power.source.no)

Arguments

E.MeV.u
energy of particles in the mixed particle field (array of size number.of.field.components) (see also E.MeV.u).
particle.no
particle index (array of size number.of.field.components) (see also particle.no).
fluence.cm2
fluences of particles in the mixed particle field (array of size number.of.field.components).
material.no
material index (see also material.no).
stopping.power.source.no
TODO (see also stopping.power.source.no).

Value

  • dose-weighteddose-weighted

See Also

View the C source code here: http://sourceforge.net/apps/trac/libamtrack/browser/tags/0.6.3/src/AT_Phy sicsRoutines.c#L600

Examples

Run this code
# fluence- and dose-weighted mean energy for a simple mixed field
# of high and low (99/1) energy protons
AT.fluence.weighted.E.MeV.u( E.MeV.u       = c(100, 1),
                             fluence.cm2   = c(99e8, 1e8)) 
AT.dose.weighted.E.MeV.u( E.MeV.u       = c(100, 1),
                          particle.no   = c(1001, 1001),
                          fluence.cm2   = c(99e8, 1e8), 
                          material.no   = 1,                   # water
                                   stopping.power.source.no = 2)

Run the code above in your browser using DataLab