AT.energy.straggling.after.slab.E.MeV.u: AT.energy.straggling.after.slab.E.MeV.u
Description
Get energy spread of an ion beam after traversing
a material slab according to Bohr's classical theory.
Bohr, N. (1915), Phil. Mag. 30, 581ff, see also Evans, R.D. (1955), The
atomic nucleus, McGraw Hill, New York, p. 661
Please note that the effective charge is assumed to be constant over the
material slab
If this is not the case you should apply this routine multiple times to
subslicesUsage
AT.energy.straggling.after.slab.E.MeV.u(E.MeV.u, particle.no,
material.no, slab.thickness.m, initial.sigma.E.MeV.u)
Arguments
E.MeV.u
vector of energies of particle per nucleon [MeV] (array of
size n) (see also E.MeV.u). particle.no
type of the particles in the mixed particle field (array
of size n) (see also particle.no). slab.thickness.m
thickness of slab in m.
initial.sigma.E.MeV.u
energy spread - 1 sigma - before traversing
the slab - can be 0 (array of size n).
Value
- sigma.E.MeV.uenergy spread - 1 sigma - after traversing the slab
(array of size n)
See Also
View the C source code here:
http://sourceforge.net/apps/trac/libamtrack/browser/tags/0.6.3/src/AT_Phy
sicsRoutines.c#L318