Learn R Programming

libamtrack (version 0.6.3)

AT.max.E.transfer.MeV.new: AT.max.E.transfer.MeV.new

Description

Kinetic energy maximally transferred from an ion to an electron in a collision - relativistic or non-relativistic

Usage

AT.max.E.transfer.MeV.new(E.MeV.u, A)

Arguments

E.MeV.u
energies of particle per nucleon [MeV/u]; if positive, the computation will be relativistic; if negative, the classic formular will be used (array of size n) (see also E.MeV.u).
A
atomic mass (array of size n).

Value

  • max.E.transfer.MeVmaximal energies transferred (array of size n)
  • statusstatus

See Also

View the C source code here: http://sourceforge.net/apps/trac/libamtrack/browser/tags/0.6.3/src/AT_Phy sicsRoutines.c#L209