particle.no. All particles of an
individual component are supposed to have exactly the same energy (given by
particle.no), without spread. Thus an energy distribution has
to be describe in discrete energy steps.
Below is a compilation of the arguments a mixed field is described by.
Depending on the function all or a subset are necessary. If arrays of length
> number.of.field.components are entered, the additional data will be
ignored. If array hold too few data, the computation will not be executed.number.of.field.components, see also E.MeV.unumber.of.field.components), see also particle.nonumber.of.field.components), see also
fluence.cm2.or.dose.Gy