Reads USRBIN output for a series of regions, also for multiple
output files from cluster runs. As USRBIN (regions, option 12.0) scores
energy deposited per primary weight (GeV), both the region volume(s) and
density(ies) have to be given for dose computation.
Experiment name, i.e. name of input file (without '.inp'
extension)
number.of.runs
Number of output files from parallel (cluster) runs.
unit
FLUKA output unit number
data.source
'local' if output files are from a local machine,
'condor' if from condor cluster, 'condor_cleaned' if from condor cluster with
clean option (-c) in rcfluka.py
vol.cm3
Volume of regions, either single value (will be applied to
all regions) or vector of length matching the number of regions (individual
volume for each region).
density.g.cm3
Physical density of regions, either single value (will
be applied to all regions) or vector of length matching the number of regions
(individual density for each region).
Value
Data frame with deposited energy, deposited dose (and in case of multiple
runs estimate of their standard deviation) for each region.