depth the spectrum should be taken at (up to now, the
data from the closest depth step will be taken)
interpolate
if true, the spectra between the closest depth steps
will be linearly interpolated, if false, the depth step just in front of the
chosen depth will be taken directly
Value
A data frame with the following columns (ready to use in most libamtrack
functions):